import { Routes, Route, Navigate } from 'react-router-dom'
import { ThemeProvider } from '@/components/shadcn/theme-provider'
import { SubMenuContextProvider } from '@/contexts/contexts'
import '@/assets/css/globals.css'
import '@/assets/scss/_fontawesome.scss'
import '@/assets/scss/_override.scss'
import '@/assets/scss/_searchResult.styles.scss'
import useLocaliseDocumentSetup from './i18n/useLocaliseDocumentSetup'
import Layout from '@/layout/Layout'
import Dashboard from "@/pages/Dashboard"
import Installation from '@/pages/Installation'
import IntegrationStatus from '@/pages/ARMS_DashBoard/IntegrationStatus'
import ProgressStatus from '@/pages/ARMS_DashBoard/ProgressStatus'
import ProductServiceSelection from '@/pages/ARMS_ProductService/ProductServiceSelection'
import ProductServiceCheck from '@/pages/ARMS_ProductService/ProductServiceCheck'
import ProductServiceEdit from '@/pages/ARMS_ProductService/ProductServiceEdit'
import ServiceVersionSelection from '@/pages/ARMS_ProductService/ServiceVersionSelection'
import ServiceVersionCheck from '@/pages/ARMS_ProductService/ServiceVersionCheck'
import ServiceVersionEdit from '@/pages/ARMS_ProductService/ServiceVersionEdit'

function App() {
  useLocaliseDocumentSetup()

  return (
    <ThemeProvider defaultTheme="dark"> 
      <SubMenuContextProvider>
        <Layout>
          <Routes>
            <Route path='/' element={<Dashboard /> } />
            <Route path='*' element={ <Navigate replace to="/" /> } />
            <Route path='/installation' element={<Installation /> } />
            <Route path='/integration-status' element={<IntegrationStatus /> } />
            <Route path='/progress-status' element={<ProgressStatus /> } />
            <Route path='/product-service-selection' element={<ProductServiceSelection /> } />
            <Route path='/product-service-check' element={<ProductServiceCheck /> } />
            <Route path='/product-service-edit' element={<ProductServiceEdit /> } />
            <Route path='/service-version-selection' element={<ServiceVersionSelection /> } />
            <Route path='/service-version-check' element={<ServiceVersionCheck /> } />
            <Route path='/service-version-edit' element={<ServiceVersionEdit /> } />
          </Routes>
        </Layout>
      </SubMenuContextProvider>
    </ThemeProvider>
  )
}

export default App
